summaryrefslogtreecommitdiffstats
path: root/konsole/konsole/TEPty.h
diff options
context:
space:
mode:
Diffstat (limited to 'konsole/konsole/TEPty.h')
-rw-r--r--konsole/konsole/TEPty.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/konsole/konsole/TEPty.h b/konsole/konsole/TEPty.h
index d6cee77dd..21ea3ff94 100644
--- a/konsole/konsole/TEPty.h
+++ b/konsole/konsole/TEPty.h
@@ -29,7 +29,7 @@
#include <tqvaluelist.h>
#include <tqmemarray.h>
-class TEPty: public KProcess
+class TEPty: public TDEProcess
{
Q_OBJECT
@@ -94,12 +94,12 @@ Q_OBJECT
void send_string(const char* s);
bool buffer_full() { return m_bufferFull; }
// override from KProcess to allow the client of konsolePart
// to set up things after fork() but before exec()
virtual int commSetupDoneC();
protected slots:
- void dataReceived(KProcess *, char *buf, int len);
+ void dataReceived(TDEProcess *, char *buf, int len);
public slots:
void donePty();
@@ -94,12 +94,12 @@ Q_OBJECT
void send_string(const char* s);
bool buffer_full() { return m_bufferFull; }
- // override from KProcess to allow the client of konsolePart
+ // override from TDEProcess to allow the client of konsolePart
// to set up things after fork() but before exec()
virtual int commSetupDoneC();